==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkCameraActor.java <==
// java wrapper for vtkCameraActor object
//

package vtk;
import vtk.*;

public class vtkCameraActor extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetWidthByHeightRatio_4(double id0);
  public void SetWidthByHeightRatio(double id0)
    { SetWidthByHeightRatio_4(id0); }

  private native double GetWidthByHeightRatio_5();
  public double GetWidthByHeightRatio()
    { return GetWidthByHeightRatio_5(); }

  private native int RenderOpaqueGeometry_6(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_6(id0); }

  private native int HasTranslucentPolygonalGeometry_7();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_7(); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native int GetMTime_9();
  public int GetMTime()
    { return GetMTime_9(); }

  private native long GetProperty_10();
  public vtkProperty GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_11(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_11(id0); }

  public vtkCameraActor() { super(); }

  public vtkCameraActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv7h.pkg.tar.xz: vtk/vtkCameraActor.java <==
// java wrapper for vtkCameraActor object
//

package vtk;
import vtk.*;

public class vtkCameraActor extends vtkProp3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetWidthByHeightRatio_4(double id0);
  public void SetWidthByHeightRatio(double id0)
    { SetWidthByHeightRatio_4(id0); }

  private native double GetWidthByHeightRatio_5();
  public double GetWidthByHeightRatio()
    { return GetWidthByHeightRatio_5(); }

  private native int RenderOpaqueGeometry_6(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_6(id0); }

  private native int HasTranslucentPolygonalGeometry_7();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_7(); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native int GetMTime_9();
  public int GetMTime()
    { return GetMTime_9(); }

  private native long GetProperty_10();
  public vtkProperty GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_11(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_11(id0); }

  public vtkCameraActor() { super(); }

  public vtkCameraActor(long id) { super(id); }
  public native long   VTKInit();

}
